.. # ------------------( LICENSE                             )------------------
.. # Copyright (c) 2014-2024 Beartype authors.
.. # See "LICENSE" for further details.
.. #
.. # ------------------( SYNOPSIS                            )------------------

========
Synopsis
========

This subpackage contains test modules exercising import hooks installed by the
:mod:`beartype.claw` API into the active Python process and thus "intraprocess."
